""" Base class for Collection objects
"""

import time
import datetime

from rockset.cursor import Cursor
from rockset.exception import InputError
from rockset.query import Query

from rockset.swagger_client.api import CollectionsApi


class Resource(object):
    # instance methods
    def __init__(self, client, name, workspace='commons', **kwargs):
        """Represents a single Rockset collection"""
        self.client = client
        self.workspace = workspace
        self.name = name
        self.dropped = False
        for key in kwargs:
            setattr(self, key, kwargs[key])
        return

    def __str__(self):
        """Converts the collection into a user friendly printable string"""
        return str(vars(self))

    def asdict(self):
        d = {}
        for k,v in vars(self).items():
            if k == 'client':
                continue
            if k == 'dropped' and not self.dropped:
                continue
            d[k] = v
        return d

    def describe(self):
        kwargs = {}
        return CollectionsApi(
            self.client
        ).get(workspace=self.workspace, collection=self.name)

    def setstate(self, newstate):
        kwargs = {}
        return CollectionsApi(
            self.client
        ).get(workspace=self.workspace, collection=self.name, state=newstate)

    def drop(self):
        self.dropped = True
        CollectionsApi(self.client
                      ).delete(workspace=self.workspace, collection=self.name)
        return

    def query(self, q, **kwargs):
        return self.client.query(q=q, collection=self.name, **kwargs)


__all__ = [
    'Resource',
]



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.field_mask import FieldMask  # noqa: F401,E501


class SourceS3(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_key': 'str',
        'secret_access': 'str',
        'prefix': 'str',
        'pattern': 'str',
        'region': 'str',
        'bucket': 'str',
        'prefixes': 'list[str]',
        'format': 'str',
        'mappings': 'list[FieldMask]',
        'object_count_downloaded': 'int',
        'object_count_total': 'int',
        'object_bytes_total': 'int'
    }

    attribute_map = {
        'access_key': 'access_key',
        'secret_access': 'secret_access',
        'prefix': 'prefix',
        'pattern': 'pattern',
        'region': 'region',
        'bucket': 'bucket',
        'prefixes': 'prefixes',
        'format': 'format',
        'mappings': 'mappings',
        'object_count_downloaded': 'object_count_downloaded',
        'object_count_total': 'object_count_total',
        'object_bytes_total': 'object_bytes_total'
    }

    def __init__(self, bucket, prefixes, **kwargs):  # noqa: E501
        """SourceS3 - a model defined in Swagger"""  # noqa: E501

        self._access_key = None
        self._secret_access = None
        self._prefix = None
        self._pattern = None
        self._region = None
        self._bucket = None
        self._prefixes = None
        self._format = None
        self._mappings = None
        self._object_count_downloaded = None
        self._object_count_total = None
        self._object_bytes_total = None
        self.discriminator = None

        self.access_key = kwargs.pop('access_key', None)
        self.secret_access = kwargs.pop('secret_access', None)
        self.prefix = kwargs.pop('prefix', None)
        self.pattern = kwargs.pop('pattern', None)
        self.region = kwargs.pop('region', None)
        self.bucket = bucket
        self.prefixes = prefixes
        self.format = kwargs.pop('format', None)
        self.mappings = kwargs.pop('mappings', None)
        self.object_count_downloaded = kwargs.pop('object_count_downloaded', None)
        self.object_count_total = kwargs.pop('object_count_total', None)
        self.object_bytes_total = kwargs.pop('object_bytes_total', None)

    @property
    def access_key(self):
        """Gets the access_key of this SourceS3.  # noqa: E501

        AWS credential with ListObjects and GetObject access  # noqa: E501

        :return: The access_key of this SourceS3.  # noqa: E501
        :rtype: str
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        """Sets the access_key of this SourceS3.

        AWS credential with ListObjects and GetObject access  # noqa: E501

        :param access_key: The access_key of this SourceS3.  # noqa: E501
        :type: str
        """

        self._access_key = access_key

    @property
    def secret_access(self):
        """Gets the secret_access of this SourceS3.  # noqa: E501

        AWS credential with ListObjects and GetObject access  # noqa: E501

        :return: The secret_access of this SourceS3.  # noqa: E501
        :rtype: str
        """
        return self._secret_access

    @secret_access.setter
    def secret_access(self, secret_access):
        """Sets the secret_access of this SourceS3.

        AWS credential with ListObjects and GetObject access  # noqa: E501

        :param secret_access: The secret_access of this SourceS3.  # noqa: E501
        :type: str
        """

        self._secret_access = secret_access

    @property
    def prefix(self):
        """Gets the prefix of this SourceS3.  # noqa: E501

        Prefix that selects keys to ingest.  # noqa: E501

        :return: The prefix of this SourceS3.  # noqa: E501
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """Sets the prefix of this SourceS3.

        Prefix that selects keys to ingest.  # noqa: E501

        :param prefix: The prefix of this SourceS3.  # noqa: E501
        :type: str
        """

        self._prefix = prefix

    @property
    def pattern(self):
        """Gets the pattern of this SourceS3.  # noqa: E501

        Pattern that selects keys to ingest.  # noqa: E501

        :return: The pattern of this SourceS3.  # noqa: E501
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this SourceS3.

        Pattern that selects keys to ingest.  # noqa: E501

        :param pattern: The pattern of this SourceS3.  # noqa: E501
        :type: str
        """

        self._pattern = pattern

    @property
    def region(self):
        """Gets the region of this SourceS3.  # noqa: E501

        AWS region containing source bucket  # noqa: E501

        :return: The region of this SourceS3.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this SourceS3.

        AWS region containing source bucket  # noqa: E501

        :param region: The region of this SourceS3.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def bucket(self):
        """Gets the bucket of this SourceS3.  # noqa: E501

        address of S3 bucket containing data  # noqa: E501

        :return: The bucket of this SourceS3.  # noqa: E501
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this SourceS3.

        address of S3 bucket containing data  # noqa: E501

        :param bucket: The bucket of this SourceS3.  # noqa: E501
        :type: str
        """

        self._bucket = bucket

    @property
    def prefixes(self):
        """Gets the prefixes of this SourceS3.  # noqa: E501

        list of prefixes to paths from which data should be ingested  # noqa: E501

        :return: The prefixes of this SourceS3.  # noqa: E501
        :rtype: list[str]
        """
        return self._prefixes

    @prefixes.setter
    def prefixes(self, prefixes):
        """Sets the prefixes of this SourceS3.

        list of prefixes to paths from which data should be ingested  # noqa: E501

        :param prefixes: The prefixes of this SourceS3.  # noqa: E501
        :type: list[str]
        """

        self._prefixes = prefixes

    @property
    def format(self):
        """Gets the format of this SourceS3.  # noqa: E501

        do not use  # noqa: E501

        :return: The format of this SourceS3.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this SourceS3.

        do not use  # noqa: E501

        :param format: The format of this SourceS3.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def mappings(self):
        """Gets the mappings of this SourceS3.  # noqa: E501

        custom transformation on data field  # noqa: E501

        :return: The mappings of this SourceS3.  # noqa: E501
        :rtype: list[FieldMask]
        """
        return self._mappings

    @mappings.setter
    def mappings(self, mappings):
        """Sets the mappings of this SourceS3.

        custom transformation on data field  # noqa: E501

        :param mappings: The mappings of this SourceS3.  # noqa: E501
        :type: list[FieldMask]
        """

        self._mappings = mappings

    @property
    def object_count_downloaded(self):
        """Gets the object_count_downloaded of this SourceS3.  # noqa: E501


        :return: The object_count_downloaded of this SourceS3.  # noqa: E501
        :rtype: int
        """
        return self._object_count_downloaded

    @object_count_downloaded.setter
    def object_count_downloaded(self, object_count_downloaded):
        """Sets the object_count_downloaded of this SourceS3.


        :param object_count_downloaded: The object_count_downloaded of this SourceS3.  # noqa: E501
        :type: int
        """

        self._object_count_downloaded = object_count_downloaded

    @property
    def object_count_total(self):
        """Gets the object_count_total of this SourceS3.  # noqa: E501


        :return: The object_count_total of this SourceS3.  # noqa: E501
        :rtype: int
        """
        return self._object_count_total

    @object_count_total.setter
    def object_count_total(self, object_count_total):
        """Sets the object_count_total of this SourceS3.


        :param object_count_total: The object_count_total of this SourceS3.  # noqa: E501
        :type: int
        """

        self._object_count_total = object_count_total

    @property
    def object_bytes_total(self):
        """Gets the object_bytes_total of this SourceS3.  # noqa: E501


        :return: The object_bytes_total of this SourceS3.  # noqa: E501
        :rtype: int
        """
        return self._object_bytes_total

    @object_bytes_total.setter
    def object_bytes_total(self, object_bytes_total):
        """Sets the object_bytes_total of this SourceS3.


        :param object_bytes_total: The object_bytes_total of this SourceS3.  # noqa: E501
        :type: int
        """

        self._object_bytes_total = object_bytes_total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SourceS3, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SourceS3):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



from rockset import Client
from .command_rest import RESTCommand
from .util.parse_util import parse_collection_path

from docopt import docopt
from requests_toolbelt import MultipartEncoder

import json
import os
import sys
import yaml


class Upload(RESTCommand):
    def usage(self):
        return """
usage: rock upload --help
       rock upload <collection> [<files> ...] [options]
       rock upload --file=YAML_CONFIG_FILE

Add local files to a collection

arguments for `rock upload`:
  <collection>      name of the collection you wish to add data. Defaults to 'commons' workspace.
                    For collections inside other workspace, use 'workspace.collection' notation.
  <files>           add local files to the collection
                    use "-" for STDIN

options for `rock upload`:
  -h, --help                           show this help message and exit
  -f, --file <YAML configuration file>  upload all files specified in the YAML config file
  --format=CSV                         Specify the format of data. Uses the default format parameters.
                                       Use YAML file if specific format options need to be specified

examples:

    Upload a file:
        $ rock upload my-collection file.json --format=JSON

    Specify csv format parameters using yaml file:
    ```
    collection: my-collection
    files:
      - file.csv
    format_params:
      csv:
        firstLineAsColumnNames: false
        separator: ','
        columnNames:
            - c1
            - c2
        columnTypes:
            - BOOLEAN
            - INTEGER
    ```

    Specify xml format paramaters using yaml file:
    ```
    collection: my-collection
    files:
      - file.xml
    format_params:
      xml:
        root_tag: 'root'
        doc_tag: 'doc'
        attribute_prefix: '_'
        value_tag: 'my_value'
    ```

    Upload a file using yaml config:
        $ rock upload -f upload.yaml
        """

    def parse_args(self, args):
        parsed_args = dict(docopt(self.usage(), argv=args, help=False))
        if parsed_args['--help']:
            ret = self.usage()
            raise SystemExit(ret.strip())

        fn = parsed_args['--file']
        if fn:
            self.set_batch_items(
                'upload', self._parse_yaml_file(fn, upload=True)
            )
            return {}

        upload = {}

        if parsed_args['<collection>']:
            upload['collection'] = parsed_args['<collection>']

        upload['format_params'] = {}
        if not parsed_args['--format']:
            ret = "Upload file format required. Please specify with --format"
            raise SystemExit(ret)
        data_format = parsed_args['--format']
        if data_format == 'CSV':
            upload['format_params'] = {'csv': {'firstLineAsColumnNames': False}}
        elif data_format == 'XML':
            upload['format_params'] = {'xml': {'doc_tag': ''}}

        files = []
        for localfile_path in parsed_args['<files>']:
            files.append(localfile_path)

        upload['files'] = files
        return {'upload': upload}

    def _input(self):
        return sys.stdin

    def go(self):
        client = Client(api_key=self.api_key, api_server=self.api_server)
        files = self.upload.pop('files')
        for localfile_path in files:
            try:
                localfile = None
                if localfile_path == '-':
                    localfile = self._input()
                    localfile_contents = localfile.read()
                    encoder = MultipartEncoder(
                        {
                            'file': ('input', localfile_contents, None),
                            'size': str(len(localfile_contents))
                        }
                    )
                else:
                    try:
                        index = localfile_path.rindex('/') + 1
                    except ValueError as e:
                        index = 0

                    size = os.path.getsize(localfile_path)
                    file_name = localfile_path[index:]
                    params = '{}'
                    if 'format_params' in self.upload:
                        params = json.dumps((self.upload['format_params']))
                    localfile = open(localfile_path, 'rb')
                    encoder = MultipartEncoder(
                        {
                            'file': (file_name, localfile, None),
                            'params': params,
                            'size': str(size)
                        }
                    )

                path = self.upload['collection']
                workspace, name = parse_collection_path(path)
                path = '/v1/orgs/{}/ws/{}/collections/{}/uploads'.format(
                    'self', workspace, name
                )
                resp = self.post(
                    path,
                    data=encoder,
                    headers={'Content-Type': encoder.content_type},
                    timeout=None
                )['data']
                self.print_list_json(0, [resp])
            except (OSError, IOError) as e:
                self.error(
                    'Skipping file {} : Unable to open: {}'.format(
                        localfile_path, str(e)
                    )
                )
                continue
            finally:
                if localfile_path != '-' and localfile:
                    localfile.close()

        return 0



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ErrorModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message': 'str',
        'type': 'str',
        'line': 'int',
        'column': 'int',
        'trace_id': 'str',
        'error_id': 'str'
    }

    attribute_map = {
        'message': 'message',
        'type': 'type',
        'line': 'line',
        'column': 'column',
        'trace_id': 'trace_id',
        'error_id': 'error_id'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """ErrorModel - a model defined in Swagger"""  # noqa: E501

        self._message = None
        self._type = None
        self._line = None
        self._column = None
        self._trace_id = None
        self._error_id = None
        self.discriminator = None

        self.message = kwargs.pop('message', None)
        self.type = kwargs.pop('type', None)
        self.line = kwargs.pop('line', None)
        self.column = kwargs.pop('column', None)
        self.trace_id = kwargs.pop('trace_id', None)
        self.error_id = kwargs.pop('error_id', None)

    @property
    def message(self):
        """Gets the message of this ErrorModel.  # noqa: E501

        descriptive message about the error  # noqa: E501

        :return: The message of this ErrorModel.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ErrorModel.

        descriptive message about the error  # noqa: E501

        :param message: The message of this ErrorModel.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def type(self):
        """Gets the type of this ErrorModel.  # noqa: E501

        category of the error  # noqa: E501

        :return: The type of this ErrorModel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ErrorModel.

        category of the error  # noqa: E501

        :param type: The type of this ErrorModel.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def line(self):
        """Gets the line of this ErrorModel.  # noqa: E501

        Line where the error happened (if applicable)  # noqa: E501

        :return: The line of this ErrorModel.  # noqa: E501
        :rtype: int
        """
        return self._line

    @line.setter
    def line(self, line):
        """Sets the line of this ErrorModel.

        Line where the error happened (if applicable)  # noqa: E501

        :param line: The line of this ErrorModel.  # noqa: E501
        :type: int
        """

        self._line = line

    @property
    def column(self):
        """Gets the column of this ErrorModel.  # noqa: E501

        Column where the error happened (if applicable)  # noqa: E501

        :return: The column of this ErrorModel.  # noqa: E501
        :rtype: int
        """
        return self._column

    @column.setter
    def column(self, column):
        """Sets the column of this ErrorModel.

        Column where the error happened (if applicable)  # noqa: E501

        :param column: The column of this ErrorModel.  # noqa: E501
        :type: int
        """

        self._column = column

    @property
    def trace_id(self):
        """Gets the trace_id of this ErrorModel.  # noqa: E501

        Internal trace ID to help with debugging  # noqa: E501

        :return: The trace_id of this ErrorModel.  # noqa: E501
        :rtype: str
        """
        return self._trace_id

    @trace_id.setter
    def trace_id(self, trace_id):
        """Sets the trace_id of this ErrorModel.

        Internal trace ID to help with debugging  # noqa: E501

        :param trace_id: The trace_id of this ErrorModel.  # noqa: E501
        :type: str
        """

        self._trace_id = trace_id

    @property
    def error_id(self):
        """Gets the error_id of this ErrorModel.  # noqa: E501

        ID of the error  # noqa: E501

        :return: The error_id of this ErrorModel.  # noqa: E501
        :rtype: str
        """
        return self._error_id

    @error_id.setter
    def error_id(self, error_id):
        """Sets the error_id of this ErrorModel.

        ID of the error  # noqa: E501

        :param error_id: The error_id of this ErrorModel.  # noqa: E501
        :type: str
        """

        self._error_id = error_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ErrorModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.alias import Alias  # noqa: F401,E501
from rockset.swagger_client.models.collection_stats import CollectionStats  # noqa: F401,E501
from rockset.swagger_client.models.field_mapping_v2 import FieldMappingV2  # noqa: F401,E501
from rockset.swagger_client.models.field_partition import FieldPartition  # noqa: F401,E501
from rockset.swagger_client.models.field_schema import FieldSchema  # noqa: F401,E501
from rockset.swagger_client.models.inverted_index_group_encoding_options import InvertedIndexGroupEncodingOptions  # noqa: F401,E501
from rockset.swagger_client.models.source import Source  # noqa: F401,E501


class Collection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'created_by': 'str',
        'name': 'str',
        'description': 'str',
        'workspace': 'str',
        'status': 'str',
        'sources': 'list[Source]',
        'stats': 'CollectionStats',
        'retention_secs': 'int',
        'field_mappings': 'list[FieldMappingV2]',
        'clustering_key': 'list[FieldPartition]',
        'aliases': 'list[Alias]',
        'field_schemas': 'list[FieldSchema]',
        'inverted_index_group_encoding_options': 'InvertedIndexGroupEncodingOptions',
        'field_partitions': 'list[FieldPartition]'
    }

    attribute_map = {
        'created_at': 'created_at',
        'created_by': 'created_by',
        'name': 'name',
        'description': 'description',
        'workspace': 'workspace',
        'status': 'status',
        'sources': 'sources',
        'stats': 'stats',
        'retention_secs': 'retention_secs',
        'field_mappings': 'field_mappings',
        'clustering_key': 'clustering_key',
        'aliases': 'aliases',
        'field_schemas': 'field_schemas',
        'inverted_index_group_encoding_options': 'inverted_index_group_encoding_options',
        'field_partitions': 'fieldPartitions'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """Collection - a model defined in Swagger"""  # noqa: E501

        self._created_at = None
        self._created_by = None
        self._name = None
        self._description = None
        self._workspace = None
        self._status = None
        self._sources = None
        self._stats = None
        self._retention_secs = None
        self._field_mappings = None
        self._clustering_key = None
        self._aliases = None
        self._field_schemas = None
        self._inverted_index_group_encoding_options = None
        self._field_partitions = None
        self.discriminator = None

        self.created_at = kwargs.pop('created_at', None)
        self.created_by = kwargs.pop('created_by', None)
        self.name = kwargs.pop('name', None)
        self.description = kwargs.pop('description', None)
        self.workspace = kwargs.pop('workspace', None)
        self.status = kwargs.pop('status', None)
        self.sources = kwargs.pop('sources', None)
        self.stats = kwargs.pop('stats', None)
        self.retention_secs = kwargs.pop('retention_secs', None)
        self.field_mappings = kwargs.pop('field_mappings', None)
        self.clustering_key = kwargs.pop('clustering_key', None)
        self.aliases = kwargs.pop('aliases', None)
        self.field_schemas = kwargs.pop('field_schemas', None)
        self.inverted_index_group_encoding_options = kwargs.pop('inverted_index_group_encoding_options', None)
        self.field_partitions = kwargs.pop('field_partitions', None)

    @property
    def created_at(self):
        """Gets the created_at of this Collection.  # noqa: E501

        ISO-8601 date  # noqa: E501

        :return: The created_at of this Collection.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Collection.

        ISO-8601 date  # noqa: E501

        :param created_at: The created_at of this Collection.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def created_by(self):
        """Gets the created_by of this Collection.  # noqa: E501

        email of user who created the collection  # noqa: E501

        :return: The created_by of this Collection.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Collection.

        email of user who created the collection  # noqa: E501

        :param created_by: The created_by of this Collection.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def name(self):
        """Gets the name of this Collection.  # noqa: E501

        unique identifer for collection, can contain alphanumeric or dash characters  # noqa: E501

        :return: The name of this Collection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Collection.

        unique identifer for collection, can contain alphanumeric or dash characters  # noqa: E501

        :param name: The name of this Collection.  # noqa: E501
        :type: str
        """
        if name is not None and not re.search('^[A-Za-z0-9_\\-.]+$', name):  # noqa: E501
            raise ValueError("Invalid value for `name`, must be a follow pattern or equal to `/^[A-Za-z0-9_\\-.]+$/`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this Collection.  # noqa: E501

        text describing the collection  # noqa: E501

        :return: The description of this Collection.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Collection.

        text describing the collection  # noqa: E501

        :param description: The description of this Collection.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def workspace(self):
        """Gets the workspace of this Collection.  # noqa: E501

        name of the workspace that the collection is in  # noqa: E501

        :return: The workspace of this Collection.  # noqa: E501
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this Collection.

        name of the workspace that the collection is in  # noqa: E501

        :param workspace: The workspace of this Collection.  # noqa: E501
        :type: str
        """

        self._workspace = workspace

    @property
    def status(self):
        """Gets the status of this Collection.  # noqa: E501

        current status of collection, one of: CREATED, READY, DELETED  # noqa: E501

        :return: The status of this Collection.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Collection.

        current status of collection, one of: CREATED, READY, DELETED  # noqa: E501

        :param status: The status of this Collection.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def sources(self):
        """Gets the sources of this Collection.  # noqa: E501

        list of sources from which collection ingests  # noqa: E501

        :return: The sources of this Collection.  # noqa: E501
        :rtype: list[Source]
        """
        return self._sources

    @sources.setter
    def sources(self, sources):
        """Sets the sources of this Collection.

        list of sources from which collection ingests  # noqa: E501

        :param sources: The sources of this Collection.  # noqa: E501
        :type: list[Source]
        """

        self._sources = sources

    @property
    def stats(self):
        """Gets the stats of this Collection.  # noqa: E501

        metrics about the collection  # noqa: E501

        :return: The stats of this Collection.  # noqa: E501
        :rtype: CollectionStats
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Sets the stats of this Collection.

        metrics about the collection  # noqa: E501

        :param stats: The stats of this Collection.  # noqa: E501
        :type: CollectionStats
        """

        self._stats = stats

    @property
    def retention_secs(self):
        """Gets the retention_secs of this Collection.  # noqa: E501

        number of seconds after which data is purged based on event time  # noqa: E501

        :return: The retention_secs of this Collection.  # noqa: E501
        :rtype: int
        """
        return self._retention_secs

    @retention_secs.setter
    def retention_secs(self, retention_secs):
        """Sets the retention_secs of this Collection.

        number of seconds after which data is purged based on event time  # noqa: E501

        :param retention_secs: The retention_secs of this Collection.  # noqa: E501
        :type: int
        """

        self._retention_secs = retention_secs

    @property
    def field_mappings(self):
        """Gets the field_mappings of this Collection.  # noqa: E501

        list of mappings applied on all documents in a collection  # noqa: E501

        :return: The field_mappings of this Collection.  # noqa: E501
        :rtype: list[FieldMappingV2]
        """
        return self._field_mappings

    @field_mappings.setter
    def field_mappings(self, field_mappings):
        """Sets the field_mappings of this Collection.

        list of mappings applied on all documents in a collection  # noqa: E501

        :param field_mappings: The field_mappings of this Collection.  # noqa: E501
        :type: list[FieldMappingV2]
        """

        self._field_mappings = field_mappings

    @property
    def clustering_key(self):
        """Gets the clustering_key of this Collection.  # noqa: E501

        list of clustering fields for a collection  # noqa: E501

        :return: The clustering_key of this Collection.  # noqa: E501
        :rtype: list[FieldPartition]
        """
        return self._clustering_key

    @clustering_key.setter
    def clustering_key(self, clustering_key):
        """Sets the clustering_key of this Collection.

        list of clustering fields for a collection  # noqa: E501

        :param clustering_key: The clustering_key of this Collection.  # noqa: E501
        :type: list[FieldPartition]
        """

        self._clustering_key = clustering_key

    @property
    def aliases(self):
        """Gets the aliases of this Collection.  # noqa: E501

        list of aliases for a collection  # noqa: E501

        :return: The aliases of this Collection.  # noqa: E501
        :rtype: list[Alias]
        """
        return self._aliases

    @aliases.setter
    def aliases(self, aliases):
        """Sets the aliases of this Collection.

        list of aliases for a collection  # noqa: E501

        :param aliases: The aliases of this Collection.  # noqa: E501
        :type: list[Alias]
        """

        self._aliases = aliases

    @property
    def field_schemas(self):
        """Gets the field_schemas of this Collection.  # noqa: E501

        list of field schemas   # noqa: E501

        :return: The field_schemas of this Collection.  # noqa: E501
        :rtype: list[FieldSchema]
        """
        return self._field_schemas

    @field_schemas.setter
    def field_schemas(self, field_schemas):
        """Sets the field_schemas of this Collection.

        list of field schemas   # noqa: E501

        :param field_schemas: The field_schemas of this Collection.  # noqa: E501
        :type: list[FieldSchema]
        """

        self._field_schemas = field_schemas

    @property
    def inverted_index_group_encoding_options(self):
        """Gets the inverted_index_group_encoding_options of this Collection.  # noqa: E501

        inverted index group encoding options  # noqa: E501

        :return: The inverted_index_group_encoding_options of this Collection.  # noqa: E501
        :rtype: InvertedIndexGroupEncodingOptions
        """
        return self._inverted_index_group_encoding_options

    @inverted_index_group_encoding_options.setter
    def inverted_index_group_encoding_options(self, inverted_index_group_encoding_options):
        """Sets the inverted_index_group_encoding_options of this Collection.

        inverted index group encoding options  # noqa: E501

        :param inverted_index_group_encoding_options: The inverted_index_group_encoding_options of this Collection.  # noqa: E501
        :type: InvertedIndexGroupEncodingOptions
        """

        self._inverted_index_group_encoding_options = inverted_index_group_encoding_options

    @property
    def field_partitions(self):
        """Gets the field_partitions of this Collection.  # noqa: E501


        :return: The field_partitions of this Collection.  # noqa: E501
        :rtype: list[FieldPartition]
        """
        return self._field_partitions

    @field_partitions.setter
    def field_partitions(self, field_partitions):
        """Sets the field_partitions of this Collection.


        :param field_partitions: The field_partitions of this Collection.  # noqa: E501
        :type: list[FieldPartition]
        """

        self._field_partitions = field_partitions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Collection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Collection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



#!/usr/bin/env python3

import sys
import traceback
import json
import unittest
from setuptools import setup
from setuptools import find_packages


def get_version():
    version = {}
    with open("rockset/version.json", 'r') as vf:
        version = json.load(vf)
    return version


def get_long_description():
    with open('DESCRIPTION_sqlcli.rst', encoding='utf-8') as fd:
        long_description = fd.read()
    long_description += '\n'
    with open('RELEASE.rst', encoding='utf-8') as fd:
        long_description += fd.read()
    return long_description


# TODO: Add tests for rock-sql
setup(
    name='rockset_sqlcli',
    version=get_version().get('python', '???'),
    description='Rockset SQL REPL for `rock sql`',
    long_description=get_long_description(),
    author='Rockset, Inc',
    author_email='api@rockset.io',
    url='https://rockset.com',
    keywords="Rockset serverless search and analytics",
    packages=find_packages(include=[
        'rockset_sqlcli',
        'rockset_sqlcli.*',
    ], ),
    install_requires=[
        'cli_helpers[styles] >= 1.0.1',
        'click >= 4.1',
        'configobj >= 5.0.6',
        'humanize >= 0.5.1',
        'prompt_toolkit == 1.0.13',
        'Pygments >= 2.0',
        'pyyaml >= 3.11',
        'rockset >= 0.6.0b20190617 ',
        'sqlparse >= 0.2.2',
        'webcolors >= 1.7',
    ],
    entry_points={
        'console_scripts': ['rock-sql = rockset_sqlcli.main:main', ],
    },
    classifiers=[
        'License :: OSI Approved :: BSD License',
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Environment :: Other Environment',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Intended Audience :: Science/Research',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: SQL',
        'Topic :: Database',
        'Topic :: Database :: Database Engines/Servers',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: System :: Shells',
        'Topic :: Internet :: WWW/HTTP :: Indexing/Search',
    ],
    package_data={
        'rockset_sqlcli':
            [
                'README.rst',
                'pgcli-AUTHORS',
                'pgcli-LICENSE.txt',
                'rscli/rsclirc',
                'rscli/packages/rsliterals/rsliterals.json',
            ],
    },
)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StatusMongoDb(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'scan_start_time': 'str',
        'scan_end_time': 'str',
        'scan_records_processed': 'int',
        'scan_total_records': 'int',
        'state': 'str',
        'stream_last_insert_processed_at': 'str',
        'stream_last_update_processed_at': 'str',
        'stream_last_delete_processed_at': 'str',
        'stream_records_inserted': 'int',
        'stream_records_updated': 'int',
        'stream_records_deleted': 'int'
    }

    attribute_map = {
        'scan_start_time': 'scan_start_time',
        'scan_end_time': 'scan_end_time',
        'scan_records_processed': 'scan_records_processed',
        'scan_total_records': 'scan_total_records',
        'state': 'state',
        'stream_last_insert_processed_at': 'stream_last_insert_processed_at',
        'stream_last_update_processed_at': 'stream_last_update_processed_at',
        'stream_last_delete_processed_at': 'stream_last_delete_processed_at',
        'stream_records_inserted': 'stream_records_inserted',
        'stream_records_updated': 'stream_records_updated',
        'stream_records_deleted': 'stream_records_deleted'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """StatusMongoDb - a model defined in Swagger"""  # noqa: E501

        self._scan_start_time = None
        self._scan_end_time = None
        self._scan_records_processed = None
        self._scan_total_records = None
        self._state = None
        self._stream_last_insert_processed_at = None
        self._stream_last_update_processed_at = None
        self._stream_last_delete_processed_at = None
        self._stream_records_inserted = None
        self._stream_records_updated = None
        self._stream_records_deleted = None
        self.discriminator = None

        self.scan_start_time = kwargs.pop('scan_start_time', None)
        self.scan_end_time = kwargs.pop('scan_end_time', None)
        self.scan_records_processed = kwargs.pop('scan_records_processed', None)
        self.scan_total_records = kwargs.pop('scan_total_records', None)
        self.state = kwargs.pop('state', None)
        self.stream_last_insert_processed_at = kwargs.pop('stream_last_insert_processed_at', None)
        self.stream_last_update_processed_at = kwargs.pop('stream_last_update_processed_at', None)
        self.stream_last_delete_processed_at = kwargs.pop('stream_last_delete_processed_at', None)
        self.stream_records_inserted = kwargs.pop('stream_records_inserted', None)
        self.stream_records_updated = kwargs.pop('stream_records_updated', None)
        self.stream_records_deleted = kwargs.pop('stream_records_deleted', None)

    @property
    def scan_start_time(self):
        """Gets the scan_start_time of this StatusMongoDb.  # noqa: E501

        MongoDB scan start time  # noqa: E501

        :return: The scan_start_time of this StatusMongoDb.  # noqa: E501
        :rtype: str
        """
        return self._scan_start_time

    @scan_start_time.setter
    def scan_start_time(self, scan_start_time):
        """Sets the scan_start_time of this StatusMongoDb.

        MongoDB scan start time  # noqa: E501

        :param scan_start_time: The scan_start_time of this StatusMongoDb.  # noqa: E501
        :type: str
        """

        self._scan_start_time = scan_start_time

    @property
    def scan_end_time(self):
        """Gets the scan_end_time of this StatusMongoDb.  # noqa: E501

        MongoDB scan end time  # noqa: E501

        :return: The scan_end_time of this StatusMongoDb.  # noqa: E501
        :rtype: str
        """
        return self._scan_end_time

    @scan_end_time.setter
    def scan_end_time(self, scan_end_time):
        """Sets the scan_end_time of this StatusMongoDb.

        MongoDB scan end time  # noqa: E501

        :param scan_end_time: The scan_end_time of this StatusMongoDb.  # noqa: E501
        :type: str
        """

        self._scan_end_time = scan_end_time

    @property
    def scan_records_processed(self):
        """Gets the scan_records_processed of this StatusMongoDb.  # noqa: E501

        Number of records inserted using scan  # noqa: E501

        :return: The scan_records_processed of this StatusMongoDb.  # noqa: E501
        :rtype: int
        """
        return self._scan_records_processed

    @scan_records_processed.setter
    def scan_records_processed(self, scan_records_processed):
        """Sets the scan_records_processed of this StatusMongoDb.

        Number of records inserted using scan  # noqa: E501

        :param scan_records_processed: The scan_records_processed of this StatusMongoDb.  # noqa: E501
        :type: int
        """

        self._scan_records_processed = scan_records_processed

    @property
    def scan_total_records(self):
        """Gets the scan_total_records of this StatusMongoDb.  # noqa: E501

        Number of records in MongoDB table at time of scan  # noqa: E501

        :return: The scan_total_records of this StatusMongoDb.  # noqa: E501
        :rtype: int
        """
        return self._scan_total_records

    @scan_total_records.setter
    def scan_total_records(self, scan_total_records):
        """Sets the scan_total_records of this StatusMongoDb.

        Number of records in MongoDB table at time of scan  # noqa: E501

        :param scan_total_records: The scan_total_records of this StatusMongoDb.  # noqa: E501
        :type: int
        """

        self._scan_total_records = scan_total_records

    @property
    def state(self):
        """Gets the state of this StatusMongoDb.  # noqa: E501

        state of current ingest for this table  # noqa: E501

        :return: The state of this StatusMongoDb.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this StatusMongoDb.

        state of current ingest for this table  # noqa: E501

        :param state: The state of this StatusMongoDb.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def stream_last_insert_processed_at(self):
        """Gets the stream_last_insert_processed_at of this StatusMongoDb.  # noqa: E501

        ISO-8601 date when new insert from source was last processed  # noqa: E501

        :return: The stream_last_insert_processed_at of this StatusMongoDb.  # noqa: E501
        :rtype: str
        """
        return self._stream_last_insert_processed_at

    @stream_last_insert_processed_at.setter
    def stream_last_insert_processed_at(self, stream_last_insert_processed_at):
        """Sets the stream_last_insert_processed_at of this StatusMongoDb.

        ISO-8601 date when new insert from source was last processed  # noqa: E501

        :param stream_last_insert_processed_at: The stream_last_insert_processed_at of this StatusMongoDb.  # noqa: E501
        :type: str
        """

        self._stream_last_insert_processed_at = stream_last_insert_processed_at

    @property
    def stream_last_update_processed_at(self):
        """Gets the stream_last_update_processed_at of this StatusMongoDb.  # noqa: E501

        ISO-8601 date when update from source was last processed  # noqa: E501

        :return: The stream_last_update_processed_at of this StatusMongoDb.  # noqa: E501
        :rtype: str
        """
        return self._stream_last_update_processed_at

    @stream_last_update_processed_at.setter
    def stream_last_update_processed_at(self, stream_last_update_processed_at):
        """Sets the stream_last_update_processed_at of this StatusMongoDb.

        ISO-8601 date when update from source was last processed  # noqa: E501

        :param stream_last_update_processed_at: The stream_last_update_processed_at of this StatusMongoDb.  # noqa: E501
        :type: str
        """

        self._stream_last_update_processed_at = stream_last_update_processed_at

    @property
    def stream_last_delete_processed_at(self):
        """Gets the stream_last_delete_processed_at of this StatusMongoDb.  # noqa: E501

        ISO-8601 date when delete from source was last processed  # noqa: E501

        :return: The stream_last_delete_processed_at of this StatusMongoDb.  # noqa: E501
        :rtype: str
        """
        return self._stream_last_delete_processed_at

    @stream_last_delete_processed_at.setter
    def stream_last_delete_processed_at(self, stream_last_delete_processed_at):
        """Sets the stream_last_delete_processed_at of this StatusMongoDb.

        ISO-8601 date when delete from source was last processed  # noqa: E501

        :param stream_last_delete_processed_at: The stream_last_delete_processed_at of this StatusMongoDb.  # noqa: E501
        :type: str
        """

        self._stream_last_delete_processed_at = stream_last_delete_processed_at

    @property
    def stream_records_inserted(self):
        """Gets the stream_records_inserted of this StatusMongoDb.  # noqa: E501

        Number of new records inserted using stream  # noqa: E501

        :return: The stream_records_inserted of this StatusMongoDb.  # noqa: E501
        :rtype: int
        """
        return self._stream_records_inserted

    @stream_records_inserted.setter
    def stream_records_inserted(self, stream_records_inserted):
        """Sets the stream_records_inserted of this StatusMongoDb.

        Number of new records inserted using stream  # noqa: E501

        :param stream_records_inserted: The stream_records_inserted of this StatusMongoDb.  # noqa: E501
        :type: int
        """

        self._stream_records_inserted = stream_records_inserted

    @property
    def stream_records_updated(self):
        """Gets the stream_records_updated of this StatusMongoDb.  # noqa: E501

        Number of new records updated using stream  # noqa: E501

        :return: The stream_records_updated of this StatusMongoDb.  # noqa: E501
        :rtype: int
        """
        return self._stream_records_updated

    @stream_records_updated.setter
    def stream_records_updated(self, stream_records_updated):
        """Sets the stream_records_updated of this StatusMongoDb.

        Number of new records updated using stream  # noqa: E501

        :param stream_records_updated: The stream_records_updated of this StatusMongoDb.  # noqa: E501
        :type: int
        """

        self._stream_records_updated = stream_records_updated

    @property
    def stream_records_deleted(self):
        """Gets the stream_records_deleted of this StatusMongoDb.  # noqa: E501

        Number of new records deleted using stream  # noqa: E501

        :return: The stream_records_deleted of this StatusMongoDb.  # noqa: E501
        :rtype: int
        """
        return self._stream_records_deleted

    @stream_records_deleted.setter
    def stream_records_deleted(self, stream_records_deleted):
        """Sets the stream_records_deleted of this StatusMongoDb.

        Number of new records deleted using stream  # noqa: E501

        :param stream_records_deleted: The stream_records_deleted of this StatusMongoDb.  # noqa: E501
        :type: int
        """

        self._stream_records_deleted = stream_records_deleted

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StatusMongoDb, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatusMongoDb):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



from .command_auth import AuthCommand
from .util.type_util import TypeUtil
from .util.parse_util import parse_collection_path
from rockset.swagger_client.api import CollectionsApi

from docopt import docopt


class Describe(AuthCommand):
    def usage(self):
        return """
usage: rock describe [-ah] <resource-type> <name> ...

Show details about collections or integrations.

arguments:
    <name>                name of the collection or integration
    <resource-type>       oneof collections or integrations.

Valid resource types:
  * collections (aka 'col')
  * integrations (aka 'int')
  * workspaces (aka 'ws')

options:
    -a, --all           display extended stats
    -h, --help          show this help message and exit"""

    def parse_args(self, args):
        parsed_args = dict(docopt(self.usage(), argv=args))
        if parsed_args['--help']:
            ret = self.usage()
            raise SystemExit(ret.strip())

        resource_type = TypeUtil.parse_resource_type(
            parsed_args['<resource-type>']
        )
        if resource_type is None:
            ret = 'Error: invalid resource type "{}"\n'.format(resource_type)
            ret += self.usage()
            raise SystemExit(ret.strip())
        return {
            "resource": {
                'type': resource_type,
                'name': parsed_args['<name>']
            }
        }

    def go(self):
        self.logger.info('describe {}'.format(self.resource))
        if self.resource["type"] == TypeUtil.TYPE_COLLECTION:
            return self.go_collection()
        elif self.resource["type"] == TypeUtil.TYPE_INTEGRATION:
            return self.go_integration()
        elif self.resource["type"] == TypeUtil.TYPE_WORKSPACE:
            return self.go_workspace()
        else:
            return 1

    def go_collection(self):
        for name in self.resource['name']:
            workspace_name, collection_name = parse_collection_path(name)
            collection = CollectionsApi(
                self.client
            ).get(workspace=workspace_name,
                  collection=collection_name).to_dict()
            collection = self.prune_empty_fields(collection)
            self.print_list(0, [collection], default='yaml')
        return 0

    def go_integration(self):
        for name in self.resource['name']:
            integration = self.client.Integration.retrieve(name).to_dict()
            integration = self.prune_empty_fields(integration)
            self.print_list(0, [integration], default='yaml')
        return 0

    def go_workspace(self):
        for name in self.resource['name']:
            workspace = self.client.Workspace.retrieve(name).to_dict()
            workspace = self.prune_empty_fields(workspace)
            self.print_list(0, [workspace], default='yaml')
        return 0



# coding: utf-8

# flake8: noqa
"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from rockset.swagger_client.models.add_documents_request import AddDocumentsRequest
from rockset.swagger_client.models.add_documents_response import AddDocumentsResponse
from rockset.swagger_client.models.alias import Alias
from rockset.swagger_client.models.api_key import ApiKey
from rockset.swagger_client.models.aws_access_key import AwsAccessKey
from rockset.swagger_client.models.aws_role import AwsRole
from rockset.swagger_client.models.cluster import Cluster
from rockset.swagger_client.models.collection import Collection
from rockset.swagger_client.models.collection_stats import CollectionStats
from rockset.swagger_client.models.create_alias_request import CreateAliasRequest
from rockset.swagger_client.models.create_alias_response import CreateAliasResponse
from rockset.swagger_client.models.create_api_key_request import CreateApiKeyRequest
from rockset.swagger_client.models.create_api_key_response import CreateApiKeyResponse
from rockset.swagger_client.models.create_collection_request import CreateCollectionRequest
from rockset.swagger_client.models.create_collection_response import CreateCollectionResponse
from rockset.swagger_client.models.create_integration_request import CreateIntegrationRequest
from rockset.swagger_client.models.create_integration_response import CreateIntegrationResponse
from rockset.swagger_client.models.create_ip_allowlist_request import CreateIpAllowlistRequest
from rockset.swagger_client.models.create_ip_allowlist_response import CreateIpAllowlistResponse
from rockset.swagger_client.models.create_query_lambda_request import CreateQueryLambdaRequest
from rockset.swagger_client.models.create_query_lambda_tag_request import CreateQueryLambdaTagRequest
from rockset.swagger_client.models.create_user_request import CreateUserRequest
from rockset.swagger_client.models.create_user_response import CreateUserResponse
from rockset.swagger_client.models.create_workspace_request import CreateWorkspaceRequest
from rockset.swagger_client.models.create_workspace_response import CreateWorkspaceResponse
from rockset.swagger_client.models.csv_params import CsvParams
from rockset.swagger_client.models.delete_alias_response import DeleteAliasResponse
from rockset.swagger_client.models.delete_api_key_response import DeleteApiKeyResponse
from rockset.swagger_client.models.delete_collection_response import DeleteCollectionResponse
from rockset.swagger_client.models.delete_documents_request import DeleteDocumentsRequest
from rockset.swagger_client.models.delete_documents_request_data import DeleteDocumentsRequestData
from rockset.swagger_client.models.delete_documents_response import DeleteDocumentsResponse
from rockset.swagger_client.models.delete_integration_response import DeleteIntegrationResponse
from rockset.swagger_client.models.delete_ip_allowlist_response import DeleteIpAllowlistResponse
from rockset.swagger_client.models.delete_query_lambda_response import DeleteQueryLambdaResponse
from rockset.swagger_client.models.delete_user_response import DeleteUserResponse
from rockset.swagger_client.models.delete_workspace_response import DeleteWorkspaceResponse
from rockset.swagger_client.models.document_status import DocumentStatus
from rockset.swagger_client.models.dynamodb_integration import DynamodbIntegration
from rockset.swagger_client.models.error_model import ErrorModel
from rockset.swagger_client.models.event_time_info import EventTimeInfo
from rockset.swagger_client.models.execute_query_lambda_request import ExecuteQueryLambdaRequest
from rockset.swagger_client.models.field_mapping import FieldMapping
from rockset.swagger_client.models.field_mapping_v2 import FieldMappingV2
from rockset.swagger_client.models.field_mask import FieldMask
from rockset.swagger_client.models.field_mask_mask import FieldMaskMask
from rockset.swagger_client.models.field_options import FieldOptions
from rockset.swagger_client.models.field_partition import FieldPartition
from rockset.swagger_client.models.field_schema import FieldSchema
from rockset.swagger_client.models.format_params import FormatParams
from rockset.swagger_client.models.gcp_service_account import GcpServiceAccount
from rockset.swagger_client.models.gcs_integration import GcsIntegration
from rockset.swagger_client.models.get_alias_response import GetAliasResponse
from rockset.swagger_client.models.get_api_key_response import GetApiKeyResponse
from rockset.swagger_client.models.get_collection_response import GetCollectionResponse
from rockset.swagger_client.models.get_integration_response import GetIntegrationResponse
from rockset.swagger_client.models.get_ip_allowlist_response import GetIpAllowlistResponse
from rockset.swagger_client.models.get_virtual_instance_response import GetVirtualInstanceResponse
from rockset.swagger_client.models.get_workspace_response import GetWorkspaceResponse
from rockset.swagger_client.models.input_field import InputField
from rockset.swagger_client.models.integration import Integration
from rockset.swagger_client.models.inverted_index_group_encoding_options import InvertedIndexGroupEncodingOptions
from rockset.swagger_client.models.ip_allowlist import IpAllowlist
from rockset.swagger_client.models.kafka_integration import KafkaIntegration
from rockset.swagger_client.models.kinesis_integration import KinesisIntegration
from rockset.swagger_client.models.list_aliases_response import ListAliasesResponse
from rockset.swagger_client.models.list_api_keys_response import ListApiKeysResponse
from rockset.swagger_client.models.list_collections_response import ListCollectionsResponse
from rockset.swagger_client.models.list_integrations_response import ListIntegrationsResponse
from rockset.swagger_client.models.list_ip_allowlists_response import ListIpAllowlistsResponse
from rockset.swagger_client.models.list_query_lambda_tags_response import ListQueryLambdaTagsResponse
from rockset.swagger_client.models.list_query_lambda_versions_response import ListQueryLambdaVersionsResponse
from rockset.swagger_client.models.list_query_lambdas_response import ListQueryLambdasResponse
from rockset.swagger_client.models.list_users_response import ListUsersResponse
from rockset.swagger_client.models.list_virtual_instances_response import ListVirtualInstancesResponse
from rockset.swagger_client.models.list_workspaces_response import ListWorkspacesResponse
from rockset.swagger_client.models.mongo_db_integration import MongoDbIntegration
from rockset.swagger_client.models.org_membership import OrgMembership
from rockset.swagger_client.models.organization import Organization
from rockset.swagger_client.models.organization_response import OrganizationResponse
from rockset.swagger_client.models.output_field import OutputField
from rockset.swagger_client.models.patch_document import PatchDocument
from rockset.swagger_client.models.patch_documents_request import PatchDocumentsRequest
from rockset.swagger_client.models.patch_documents_response import PatchDocumentsResponse
from rockset.swagger_client.models.patch_operation import PatchOperation
from rockset.swagger_client.models.query_error import QueryError
from rockset.swagger_client.models.query_field_type import QueryFieldType
from rockset.swagger_client.models.query_lambda import QueryLambda
from rockset.swagger_client.models.query_lambda_sql import QueryLambdaSql
from rockset.swagger_client.models.query_lambda_stats import QueryLambdaStats
from rockset.swagger_client.models.query_lambda_tag import QueryLambdaTag
from rockset.swagger_client.models.query_lambda_tag_response import QueryLambdaTagResponse
from rockset.swagger_client.models.query_lambda_version import QueryLambdaVersion
from rockset.swagger_client.models.query_lambda_version_response import QueryLambdaVersionResponse
from rockset.swagger_client.models.query_parameter import QueryParameter
from rockset.swagger_client.models.query_request import QueryRequest
from rockset.swagger_client.models.query_request_sql import QueryRequestSql
from rockset.swagger_client.models.query_response import QueryResponse
from rockset.swagger_client.models.query_response_stats import QueryResponseStats
from rockset.swagger_client.models.redshift_integration import RedshiftIntegration
from rockset.swagger_client.models.s3_integration import S3Integration
from rockset.swagger_client.models.segment_integration import SegmentIntegration
from rockset.swagger_client.models.source import Source
from rockset.swagger_client.models.source_dynamo_db import SourceDynamoDb
from rockset.swagger_client.models.source_file_upload import SourceFileUpload
from rockset.swagger_client.models.source_gcs import SourceGcs
from rockset.swagger_client.models.source_kafka import SourceKafka
from rockset.swagger_client.models.source_kinesis import SourceKinesis
from rockset.swagger_client.models.source_mongo_db import SourceMongoDb
from rockset.swagger_client.models.source_redshift import SourceRedshift
from rockset.swagger_client.models.source_s3 import SourceS3
from rockset.swagger_client.models.sql_expression import SqlExpression
from rockset.swagger_client.models.status import Status
from rockset.swagger_client.models.status_dynamo_db import StatusDynamoDb
from rockset.swagger_client.models.status_kafka import StatusKafka
from rockset.swagger_client.models.status_kafka_partition import StatusKafkaPartition
from rockset.swagger_client.models.status_mongo_db import StatusMongoDb
from rockset.swagger_client.models.update_alias_request import UpdateAliasRequest
from rockset.swagger_client.models.update_query_lambda_request import UpdateQueryLambdaRequest
from rockset.swagger_client.models.update_virtual_instance_request import UpdateVirtualInstanceRequest
from rockset.swagger_client.models.update_virtual_instance_response import UpdateVirtualInstanceResponse
from rockset.swagger_client.models.user import User
from rockset.swagger_client.models.validate_query_response import ValidateQueryResponse
from rockset.swagger_client.models.virtual_instance import VirtualInstance
from rockset.swagger_client.models.workspace import Workspace
from rockset.swagger_client.models.xml_params import XmlParams



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.collection import Collection  # noqa: F401,E501


class ListCollectionsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'list[Collection]'
    }

    attribute_map = {
        'data': 'data'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """ListCollectionsResponse - a model defined in Swagger"""  # noqa: E501

        self._data = None
        self.discriminator = None

        self.data = kwargs.pop('data', None)

    @property
    def data(self):
        """Gets the data of this ListCollectionsResponse.  # noqa: E501

        list of all collections  # noqa: E501

        :return: The data of this ListCollectionsResponse.  # noqa: E501
        :rtype: list[Collection]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this ListCollectionsResponse.

        list of all collections  # noqa: E501

        :param data: The data of this ListCollectionsResponse.  # noqa: E501
        :type: list[Collection]
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ListCollectionsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCollectionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



from docopt import docopt

from .command_auth import AuthCommand
from .util.type_util import IntegrationType, TypeUtil


class List(AuthCommand):
    def usage(self, hidden=False):
        return """
Usage:
    rock list [-h]
    rock list collections [--workspace=WORKSPACE]
    rock list integrations
    rock list workspaces{}

Options:
  -h, --help                      show this help message and exit
  -w, --workspace=WORKSPACE       list all collections recursively within given workspace
        """.format(
            "" if not hidden else """
    rock list c [--workspace=WORKSPACE]
    rock list col [--workspace=WORKSPACE]
    rock list collection [--workspace=WORKSPACE]
    rock list i
    rock list int
    rock list integration
    rock list w
    rock list ws
    rock list workspace"""
        )

    def parse_args(self, args):
        parsed = dict(docopt(self.usage(hidden=True), argv=args, help=False))

        if parsed['--help']:
            ret = self.usage()
            raise SystemExit(ret.strip())

        if any(
            [
                parsed.get(t, 'None')
                for t in ['c', 'col', 'collection', 'collections']
            ]
        ):
            return {
                'resource': TypeUtil.TYPE_COLLECTION,
                'workspace': parsed['--workspace'],
            }

        if any(
            [
                parsed.get(t, 'None')
                for t in ['i', 'int', 'integration', 'integrations']
            ]
        ):
            return {'resource': TypeUtil.TYPE_INTEGRATION}

        if any(
            [
                parsed.get(t, 'None')
                for t in ['w', 'ws', 'workspace', 'workspaces']
            ]
        ):
            return {'resource': TypeUtil.TYPE_WORKSPACE}

        return {
            'resource': TypeUtil.TYPE_COLLECTION,
            'workspace': parsed['--workspace']
        }

    def go(self):
        if self.resource == TypeUtil.TYPE_COLLECTION:
            return self.go_collections()

        if self.resource == TypeUtil.TYPE_INTEGRATION:
            return self.go_integrations()

        if self.resource == TypeUtil.TYPE_WORKSPACE:
            return self.go_workspaces()

        return self.go_collections()

    def go_collections(self):
        fields = [
            'name', 'workspace', 'status', 'description', 'created_by',
            'created_at', 'size'
        ]
        collections = [
            c.asdict()
            for c in self.client.Collection.list(workspace=self.workspace)
        ]

        for c in collections:
            c['size'] = c.get('stats').get('total_size')
        collections.sort(
            key=lambda c: "{}.{}".format(c.get('workspace'), c.get('name'))
        )
        self.print_list(0, collections, fields)
        return 0

    def go_integrations(self):
        fields = ['type', 'name', 'description', 'created_by']
        integrations = [i.to_dict() for i in self.client.Integration.list()]
        for i in integrations:
            i['type'] = IntegrationType.parse_from_integration(i)
        integrations.sort(
            key=lambda i: "{}.{}".format(i.get('type'), i.get('name'))
        )
        self.print_list(0, integrations, fields)
        return 0

    def go_workspaces(self):
        fields = [
            'name', 'description', 'collection_count', 'created_by',
            'created_at'
        ]
        workspaces = [w.to_dict() for w in self.client.Workspace.list()]
        for w in workspaces:
            w['is_empty'] = str(w.get('collection_count') == 0)
        workspaces.sort(
            key=lambda w: "{}.{}".format(w.get('is_empty'), w.get('name'))
        )
        self.print_list(0, workspaces, fields)
        return 0



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.event_time_info import EventTimeInfo  # noqa: F401,E501
from rockset.swagger_client.models.field_mapping_v2 import FieldMappingV2  # noqa: F401,E501
from rockset.swagger_client.models.field_partition import FieldPartition  # noqa: F401,E501
from rockset.swagger_client.models.field_schema import FieldSchema  # noqa: F401,E501
from rockset.swagger_client.models.inverted_index_group_encoding_options import InvertedIndexGroupEncodingOptions  # noqa: F401,E501
from rockset.swagger_client.models.source import Source  # noqa: F401,E501


class CreateCollectionRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'sources': 'list[Source]',
        'retention_secs': 'int',
        'time_partition_resolution_secs': 'int',
        'event_time_info': 'EventTimeInfo',
        'field_mappings': 'list[FieldMappingV2]',
        'clustering_key': 'list[FieldPartition]',
        'field_schemas': 'list[FieldSchema]',
        'inverted_index_group_encoding_options': 'InvertedIndexGroupEncodingOptions'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'sources': 'sources',
        'retention_secs': 'retention_secs',
        'time_partition_resolution_secs': 'time_partition_resolution_secs',
        'event_time_info': 'event_time_info',
        'field_mappings': 'field_mappings',
        'clustering_key': 'clustering_key',
        'field_schemas': 'field_schemas',
        'inverted_index_group_encoding_options': 'inverted_index_group_encoding_options'
    }

    def __init__(self, name, **kwargs):  # noqa: E501
        """CreateCollectionRequest - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._description = None
        self._sources = None
        self._retention_secs = None
        self._time_partition_resolution_secs = None
        self._event_time_info = None
        self._field_mappings = None
        self._clustering_key = None
        self._field_schemas = None
        self._inverted_index_group_encoding_options = None
        self.discriminator = None

        self.name = name
        self.description = kwargs.pop('description', None)
        self.sources = kwargs.pop('sources', None)
        self.retention_secs = kwargs.pop('retention_secs', None)
        self.time_partition_resolution_secs = kwargs.pop('time_partition_resolution_secs', None)
        self.event_time_info = kwargs.pop('event_time_info', None)
        self.field_mappings = kwargs.pop('field_mappings', None)
        self.clustering_key = kwargs.pop('clustering_key', None)
        self.field_schemas = kwargs.pop('field_schemas', None)
        self.inverted_index_group_encoding_options = kwargs.pop('inverted_index_group_encoding_options', None)

    @property
    def name(self):
        """Gets the name of this CreateCollectionRequest.  # noqa: E501

        unique identifier for collection, can contain alphanumeric or dash characters  # noqa: E501

        :return: The name of this CreateCollectionRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateCollectionRequest.

        unique identifier for collection, can contain alphanumeric or dash characters  # noqa: E501

        :param name: The name of this CreateCollectionRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this CreateCollectionRequest.  # noqa: E501

        text describing the collection  # noqa: E501

        :return: The description of this CreateCollectionRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateCollectionRequest.

        text describing the collection  # noqa: E501

        :param description: The description of this CreateCollectionRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def sources(self):
        """Gets the sources of this CreateCollectionRequest.  # noqa: E501

        list of sources from which to ingest data  # noqa: E501

        :return: The sources of this CreateCollectionRequest.  # noqa: E501
        :rtype: list[Source]
        """
        return self._sources

    @sources.setter
    def sources(self, sources):
        """Sets the sources of this CreateCollectionRequest.

        list of sources from which to ingest data  # noqa: E501

        :param sources: The sources of this CreateCollectionRequest.  # noqa: E501
        :type: list[Source]
        """

        self._sources = sources

    @property
    def retention_secs(self):
        """Gets the retention_secs of this CreateCollectionRequest.  # noqa: E501

        number of seconds after which data is purged, based on event time  # noqa: E501

        :return: The retention_secs of this CreateCollectionRequest.  # noqa: E501
        :rtype: int
        """
        return self._retention_secs

    @retention_secs.setter
    def retention_secs(self, retention_secs):
        """Sets the retention_secs of this CreateCollectionRequest.

        number of seconds after which data is purged, based on event time  # noqa: E501

        :param retention_secs: The retention_secs of this CreateCollectionRequest.  # noqa: E501
        :type: int
        """

        self._retention_secs = retention_secs

    @property
    def time_partition_resolution_secs(self):
        """Gets the time_partition_resolution_secs of this CreateCollectionRequest.  # noqa: E501

        If non-null, the collection will be time partition and each partition will be time_partition_resolution_secs wide.  # noqa: E501

        :return: The time_partition_resolution_secs of this CreateCollectionRequest.  # noqa: E501
        :rtype: int
        """
        return self._time_partition_resolution_secs

    @time_partition_resolution_secs.setter
    def time_partition_resolution_secs(self, time_partition_resolution_secs):
        """Sets the time_partition_resolution_secs of this CreateCollectionRequest.

        If non-null, the collection will be time partition and each partition will be time_partition_resolution_secs wide.  # noqa: E501

        :param time_partition_resolution_secs: The time_partition_resolution_secs of this CreateCollectionRequest.  # noqa: E501
        :type: int
        """

        self._time_partition_resolution_secs = time_partition_resolution_secs

    @property
    def event_time_info(self):
        """Gets the event_time_info of this CreateCollectionRequest.  # noqa: E501

        configuration for event data  # noqa: E501

        :return: The event_time_info of this CreateCollectionRequest.  # noqa: E501
        :rtype: EventTimeInfo
        """
        return self._event_time_info

    @event_time_info.setter
    def event_time_info(self, event_time_info):
        """Sets the event_time_info of this CreateCollectionRequest.

        configuration for event data  # noqa: E501

        :param event_time_info: The event_time_info of this CreateCollectionRequest.  # noqa: E501
        :type: EventTimeInfo
        """

        self._event_time_info = event_time_info

    @property
    def field_mappings(self):
        """Gets the field_mappings of this CreateCollectionRequest.  # noqa: E501

        list of mappings  # noqa: E501

        :return: The field_mappings of this CreateCollectionRequest.  # noqa: E501
        :rtype: list[FieldMappingV2]
        """
        return self._field_mappings

    @field_mappings.setter
    def field_mappings(self, field_mappings):
        """Sets the field_mappings of this CreateCollectionRequest.

        list of mappings  # noqa: E501

        :param field_mappings: The field_mappings of this CreateCollectionRequest.  # noqa: E501
        :type: list[FieldMappingV2]
        """

        self._field_mappings = field_mappings

    @property
    def clustering_key(self):
        """Gets the clustering_key of this CreateCollectionRequest.  # noqa: E501

        list of clustering fields  # noqa: E501

        :return: The clustering_key of this CreateCollectionRequest.  # noqa: E501
        :rtype: list[FieldPartition]
        """
        return self._clustering_key

    @clustering_key.setter
    def clustering_key(self, clustering_key):
        """Sets the clustering_key of this CreateCollectionRequest.

        list of clustering fields  # noqa: E501

        :param clustering_key: The clustering_key of this CreateCollectionRequest.  # noqa: E501
        :type: list[FieldPartition]
        """

        self._clustering_key = clustering_key

    @property
    def field_schemas(self):
        """Gets the field_schemas of this CreateCollectionRequest.  # noqa: E501

        list of field schemas  # noqa: E501

        :return: The field_schemas of this CreateCollectionRequest.  # noqa: E501
        :rtype: list[FieldSchema]
        """
        return self._field_schemas

    @field_schemas.setter
    def field_schemas(self, field_schemas):
        """Sets the field_schemas of this CreateCollectionRequest.

        list of field schemas  # noqa: E501

        :param field_schemas: The field_schemas of this CreateCollectionRequest.  # noqa: E501
        :type: list[FieldSchema]
        """

        self._field_schemas = field_schemas

    @property
    def inverted_index_group_encoding_options(self):
        """Gets the inverted_index_group_encoding_options of this CreateCollectionRequest.  # noqa: E501

        inverted index group encoding options  # noqa: E501

        :return: The inverted_index_group_encoding_options of this CreateCollectionRequest.  # noqa: E501
        :rtype: InvertedIndexGroupEncodingOptions
        """
        return self._inverted_index_group_encoding_options

    @inverted_index_group_encoding_options.setter
    def inverted_index_group_encoding_options(self, inverted_index_group_encoding_options):
        """Sets the inverted_index_group_encoding_options of this CreateCollectionRequest.

        inverted index group encoding options  # noqa: E501

        :param inverted_index_group_encoding_options: The inverted_index_group_encoding_options of this CreateCollectionRequest.  # noqa: E501
        :type: InvertedIndexGroupEncodingOptions
        """

        self._inverted_index_group_encoding_options = inverted_index_group_encoding_options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateCollectionRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateCollectionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



from rockset import Client
from .command_rest import RESTCommand

from docopt import docopt

import json
import os
import sys
import yaml


class SetState(RESTCommand):
    def usage(self):
        return """
usage: rock setstate --help
       rock setstate <collection> <state>

Set the state of a collection to either READY or PAUSED

arguments for `rock setstate`:
  <collection>      name of the collection you wish to add data
  <state>           "READY" or "PAUSED"

options for `rock setstate`:
  -h, --help                show this help message and exit

examples:

    Set the state of a collection to READY:
        $ rock setstate my-collection READY

    Set the state of a collection to PAUSED
        $ rock setstate my-collection PAUSED

        """

    def parse_args(self, args):
        parsed_args = dict(docopt(self.usage(), argv=args, help=False))
        if parsed_args['--help']:
            ret = self.usage()
            raise SystemExit(ret.strip())

        params = {}

        if parsed_args['<collection>']:
            params['collection'] = parsed_args['<collection>']

        if parsed_args['<state>']:
            params['state'] = parsed_args['<state>'].upper()
        print(params)

        return {'params': params}

    def go(self):
        path = '/v1/orgs/{}/ws/{}/collections/{}/state/{}'.format(
            'self', 'commons', self.params['collection'], self.params['state']
        )

        deets = self.post(path)
        if 'sources' in deets:
            nsrcs = []
            for src in deets['sources']:
                nsrcs.append({k: v for k, v in src.items() if v})
            deets['data']['sources'] = nsrcs
        desc = {}
        if 'data' in deets:
            desc = {k: v for k, v in deets['data'].items() if v}
        self.print_list_yaml(0, [desc])
        return 0



from .command_auth import AuthCommand
from .util.type_util import TypeUtil
from .util.parse_util import parse_collection_path
from docopt import docopt
from rockset.exception import InputError


class Drop(AuthCommand):
    def usage(self):
        return """
usage:
  rock delete --help
  rock delete [-h] --file=YAML_CONFIG_FILE
  rock delete <resource-type> <name> ...

arguments:
    <resource-type>          oneof collections, integrations, or workspaces.
    <name>                   name of the collection/integration/workspace to be dropped

Valid resource types:
  * collections (aka 'col')
  * integrations (aka 'int')
  * workspaces (aka 'ws')

options:
    -f, --file=<YAML configuration file>    drop all resources defined in the YAML file
    -h, --help                              show this help message and exit
        """

    def parse_args(self, args):
        parsed_args = dict(docopt(self.usage(), argv=args))

        # handle file option
        fn = parsed_args['--file']
        if fn:
            parsed = self._parse_yaml_file(fn)
            self.set_batch_items('resource', parsed)
            return {}

        resource_type = TypeUtil.parse_resource_type(
            parsed_args['<resource-type>']
        )
        if resource_type is None:
            ret = 'Error: invalid resource type "{}"\n'.format(resource_type)
            ret += self.usage()
            raise SystemExit(ret.strip())

        if len(parsed_args['<name>']) > 1:
            resources = [
                {
                    'name': n,
                    'type': resource_type
                } for n in parsed_args['<name>']
            ]
            self.set_batch_items('resource', resources)
            return {}

        name = {'name': parsed_args['<name>'].pop()}
        return {"resource": {'type': resource_type, **name}}

    def go(self):
        self.logger.info('drop {}'.format(self.resource))
        if self.resource["type"] == TypeUtil.TYPE_COLLECTION:
            return self.go_collection()
        elif self.resource["type"] == TypeUtil.TYPE_INTEGRATION:
            return self.go_integration()
        elif self.resource["type"] == TypeUtil.TYPE_WORKSPACE:
            return self.go_workspace()
        else:
            return 1

    def go_collection(self):
        workspace, collection_name = parse_collection_path(
            self.resource['name']
        )
        r = self.client.retrieve(name=collection_name, workspace=workspace)
        r.drop()
        self.lprint(
            0, '{} "{}" in workspace "{}" was dropped successfully.'.format(
                r.type.capitalize(), collection_name, workspace
            )
        )
        return 0

    def go_integration(self):
        i = self.client.Integration.drop(name=self.resource['name'])
        self.lprint(
            0, '{} "{}" was dropped successfully.'.format(
                TypeUtil.TYPE_INTEGRATION.capitalize(), i.get('name')
            )
        )
        return 0

    def go_workspace(self):
        w = self.client.Workspace.drop(name=self.resource['name'])
        self.lprint(
            0, '{} "{}" was dropped successfully.'.format(
                TypeUtil.TYPE_WORKSPACE.capitalize(), w.get('name')
            )
        )
        return 0
